CurrencyPipe class

WARNING: this pipe uses the Internationalization API. Therefore it is only reliable in Chrome and Opera browsers.

Formats a number as local currency.

Usage

$pipe.currency(expression, [currencyCode, symbolDisplay, digitInfo])

where currencyCode is the ISO 4217 currency code, such as "USD" for the US dollar and "EUR" for the euro. symbolDisplay is a boolean indicating whether to use the currency symbol (e.g. $) or the currency code (e.g. USD) in the output. The default for this value is false. For more information about digitInfo see DecimalPipe

Annotations

Constructors

CurrencyPipe()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transform(num? value, [String currencyCode = 'USD', bool symbolDisplay = false, String? digits]) → String?

Operators

operator ==(Object other) → bool
The equality operator.
inherited