NoProviderError class

Thrown when there is no dependency injection provider found for a token.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → Object?
Message describing the assertion error.
finalinherited
path → List<Object>
Path of tokens traversed until it resulted in token failing.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited
token → Object
Token that failed to be found during lookup.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited