UncaughtError class

An uncaught error and stackTrace emitted by NgZone.onUncaughtError.

Annotations
  • @sealed

Constructors

UncaughtError(Object error, StackTrace stackTrace)

Properties

error → Object
An unhandled Error or Exception.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace
The stack trace associated with the uncaught error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited