ClassProvider<T extends Object> class

Describes at compile-time configuring to return an instance of a class.

If T is provided (i.e. not dynamic), it must be the same as token.

A class that provides itself:

const ClassProvider(Service);

A class that provides itself with a different implementation:

const ClassProvider(Service, useClass: CachedService);
Inheritance
Annotations
  • @optionalTypeArgs

Constructors

ClassProvider(Type type, {Type useClass})
const
factory
ClassProvider.forToken(OpaqueToken<T> token, {Type useClass})
const
factory

Properties

deps → List<Object>?
Optional; dependencies to inject and provide when invoking useFactory.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → Object
Key used for injection, commonly a Type or OpaqueToken.
finalinherited
useClass → Type?
Class whose constructor should be invoked when token is injected.
finalinherited
useExisting → Object?
An existing token to redirect to when token is injected.
finalinherited
useFactory → Function?
A factory function to invoke when token is injected.
finalinherited
useValue → Object
Constant value to use when token is injected.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited