ValueProvider<T extends Object> class

Describes at compile-time using a constant value to represent a token.

It is recommended to use useValue with an OpaqueToken as token:

const animationDelay = OpaqueToken<Duration>('animationDelay');

const ValueProvider.forToken(animationDelay, Duration(seconds: 1));

NOTE: The AngularDart compiler has limited heuristics for supporting complex nested objects beyond simple literals, including collection literals like a List or Map where you might expect specific reified types. If you encounter problems it is recommended to use FactoryProvider instead.

Inheritance
Annotations
  • @optionalTypeArgs

Constructors

ValueProvider(Type type, T useValue)
const
factory
ValueProvider.forToken(OpaqueToken<T> token, T useValue)
const
factory

Properties

deps → List<Object>?
Optional; dependencies to inject and provide when invoking useFactory.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → Object
Key used for injection, commonly a Type or OpaqueToken.
finalinherited
useClass → Type?
Class whose constructor should be invoked when token is injected.
finalinherited
useExisting → Object?
An existing token to redirect to when token is injected.
finalinherited
useFactory → Function?
A factory function to invoke when token is injected.
finalinherited
useValue → Object
Constant value to use when token is injected.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited